@@ -1,7 +1,7 @@
-from .classic.importer import DraftKingsCSVImporter
-from .classic.settings import *
-from .captain_mode.importer import DraftKingsCaptainModeCSVImporter
-from .captain_mode.settings import *
+from pydfs_lineup_optimizer.sites.draftkings.classic.importer import DraftKingsCSVImporter
+from pydfs_lineup_optimizer.sites.draftkings.classic.settings import *
+from pydfs_lineup_optimizer.sites.draftkings.captain_mode.importer import DraftKingsCaptainModeCSVImporter
+from pydfs_lineup_optimizer.sites.draftkings.captain_mode.settings import *
 
 __all__ = [
     'DraftKingsCSVImporter', 'DraftKingsBasketballSettings', 'DraftKingsFootballSettings',
