@@ -1,22 +1,22 @@
 import csv
 from pydfs_lineup_optimizer.exceptions import LineupOptimizerIncorrectCSV
 from pydfs_lineup_optimizer.lineup_importer import CSVImporter
-from pydfs_lineup_optimizer.player import Player
-from pydfs_lineup_optimizer.sites.sites_registry import SitesRegistry
-from pydfs_lineup_optimizer.constants import Site
+from pydfs_lineup_optimizer.player import Player, GameInfo
 
 
-@SitesRegistry.register_csv_importer
-class YahooCSVImporter(CSVImporter):
-    site = Site.YAHOO
-
-    def import_players(self):  # pragma: no cover
+class YahooCSVImporter(CSVImporter):  # pragma: nocover
+    def import_players(self):
         players = []
         with open(self.filename, 'r') as csvfile:
             csv_data = csv.DictReader(csvfile, skipinitialspace=True)
             for row in csv_data:
+                game_info = None
+                try:
+                    away_team, home_team = row.get('Game', '').split('@')
+                    game_info = GameInfo(home_team, away_team, None, False)
+                except ValueError:
+                    pass
                 try:
-                    max_exposure = row.get('Max Exposure')
                     player = Player(
                         row['Id'],
                         row['First Name'],
@@ -25,8 +25,9 @@ class YahooCSVImporter(CSVImporter):
                         row['Team'],
                         float(row['Salary']),
                         float(row['FPPG']),
-                        True if row['Injury Status'].strip() else False,
-                        max_exposure=float(max_exposure.replace('%', '')) if max_exposure else None
+                        is_injured=True if row['Injury Status'].strip() else False,
+                        game_info=game_info,
+                        **self.get_player_extra(row)
                     )
                 except KeyError:
                     raise LineupOptimizerIncorrectCSV
